<p align="center">
  <img src="https://cdn.prod.website-files.com/67c87d15e79883b4adbe95a7/67ffd8cd18486405cdbef943_Distributional-Logo-Horizontal-Black.png" alt="Distributional" width="600">
</p>

## Documentation

See the dbnl [documentation](https://docs.dbnl.com/).

# Distributional SDK Installation Instructions

## 1. Latest Stable Release

To install the latest stable release of the `dbnl` package:

```bash
pip install dbnl
```

## 2. Specific Release

To install a specific version (e.g., version `0.19.1`):

```bash
pip install "dbnl==0.19.1"
```

## License

[Apache License](./LICENSE)
